#!/bin/sh

#some compton control parameters:
WeightLimit=1e-9
NPhot=4000000 #initial number of photons

#output energy array definition
Delta=0.04 #logarihmic energy array bin density
Emin_out=0.0001 #low energy bound of energy array 
Emax_out=10000.0  #high energy bound of energy array

x=$(echo "l(${Emax_out}/${Emin_out})/l(10)/${Delta}"|bc -l) #x-dummy variable
Ne=$(echo "scale=0;${x}/1"|bc -l) #Ne - number of energy bins in output energy array

tau_T=${1} #1st parameter in cmdl - optical depth
kT_e=${2} #2nd parameter in cmdl - electron temperature in keV
Distribution=${3} #3th parameter in cmdl - distribution type
SEED_FILE=${4} #4th parameter in cmdl - name of input SEED file (XSPEC - format (pl eemo))

#input energy array definition (not used when SEED spectrum is read from FILE)
Emin_in=${Emin_out}
Emax_in=${Emin_out}

COMPTON_FILE=comp_tau${tau_T}_kTe${kT_e}_${Distribution}_${SEED_FILE}
COMPTON_SEED_FILE=comp_seed_tau${tau_T}_kTe${kT_e}_${SEED_FILE}
COMPTON_PATH_FILE=comp_path_tau${tau_T}_kTe${kT_e}_${Distribution}_${SEED_FILE}

kT_bb=0.1 #not used in seed file version
gamma=1.7 #not used in seed file version
efold=100.0 #not used in seed file version
COMPTON_INP=compton_inp.dat

#Other compton control parameters are defined below 
/bin/cat <<EOF >${COMPTON_INP}
ElectronTemperature = ${kT_e}
ThomsonThickness = ${tau_T}
PhotonTemperature = ${kT_bb}
NumberTrajectories = ${NPhot}
WeightLimit = ${WeightLimit}
Absorption = NO
AngularBins = 0 1
InputEnergyRange = ${Emin_in} ${Emax_in}
ElectronEnergyRange = 0.001 500
SpectrumEnergyRange = ${Emin_out} ${Emax_out} ${Ne} LOG
PathRange = 0 100 1001 LIN
OutputPhotons = SCATTERED_ONLY
ElectronSpectrum = MAXWELL
PhotonEnergyIndex = ${gamma}
FoldingEnergy = ${efold}
InitialSpectrum = FILE
SeedFile = ${SEED_FILE}
Geometry = SPHERE
Distribution = ${Distribution}
OutputUnits = keV
InitialFile = ${COMPTON_SEED_FILE}
TransmittedFile = ${COMPTON_FILE}
ReflectedFile = comp_refl.dat
PathFile = ${COMPTON_PATH_FILE}
LogFile = comp.log
EOF

echo "Running compton..."
echo "Please notice that energy array in SEED input file should not exceed following limits:"
echo "E_min >=" ${Emin_out}
echo "E_max <=" ${Emax_out}
x=$(echo "1.1*${Ne}"|bc -l)
x=$(echo "scale=0;${x}/1"|bc -l)
echo "N_bins >=" ${x}

./compton ${COMPTON_INP}

rm comp_refl.dat comp.log ${COMPTON_INP} ${COMPTON_SEED_FILE} ${COMPTON_PATH_FILE}

echo "All done."
